// Licensed Materials - Property of IBM
// 5724-P68
// Copyright IBM Corporation 2005, 2008. All Rights Reserved.
// US Government Users Restricted Rights- Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

// Alcatel-Lucent 5620 SAM Pack

var schema_oam_ping =
      PV.XMLInputSchema("SAM_oam_ping_results",
            {
		multiFileJoin:true,
		noNewInputLimit: 1,
		filePeriod: 900,
		deleteOnAcquire: true,
		parseURI: function(source) {
		source.timestamp=dateFromSAMFilename(source.localName);},
		precedence: 3,
        ignoreProcessingErrors: true},
         PV.XMLRecordSchema( "SamIcmpPingResults", { xpath:XPathExp("icmp.IcmpPingResult"),
            onRead: function(rec) { 
					rec.timestamp=this.inputSchema.currentObject.timestamp.asUTCSeconds();
					this.emitTuple(rec); 
		 }, maxOccurs: Infinity },


		PV.StringFieldSchema("timeCaptured", {xpath:XPathExp("timeCaptured")}),
		PV.StringFieldSchema("minimumRoundTripTime", {xpath:XPathExp("minimumRoundTripTime")}),
		PV.StringFieldSchema("maximumRoundTripTime", {xpath:XPathExp("maximumRoundTripTime")}),
		PV.StringFieldSchema("averageRoundTripTime", {xpath:XPathExp("averageRoundTripTime")}),
		PV.StringFieldSchema("sumOfSquaresRoundTripTime", {xpath:XPathExp("sumOfSquaresRoundTripTime")}),
		PV.StringFieldSchema("minimumInboundOneWayTime", {xpath:XPathExp("minimumOneWayTime")}),
		PV.StringFieldSchema("maximumInboundOneWayTime", {xpath:XPathExp("maximumOneWayTime")}),
		PV.StringFieldSchema("averageInboundOneWayTime", {xpath:XPathExp("averageOneWayTime")}),
		PV.StringFieldSchema("sumOfSquaresOneWayTime", {xpath:XPathExp("sumOfSquaresOneWayTime")}),
		PV.StringFieldSchema("inboundJitter", {xpath:XPathExp("inboundJitter")}),
		PV.StringFieldSchema("roundTripJitter", {xpath:XPathExp("roundTripJitter")}),
		PV.StringFieldSchema("lossPercentage", {xpath:XPathExp("lossPercentage")}),
		PV.StringFieldSchema("test", {xpath:XPathExp("test")})

			     ), // icmp.IcmpPingResult

         PV.XMLRecordSchema( "SamMplsPingResults", { xpath:XPathExp("mpls.LspPingResult"),
            onRead: function(rec) { 
					rec.timestamp=this.inputSchema.currentObject.timestamp.asUTCSeconds();
					this.emitTuple(rec); 
		 }, maxOccurs: Infinity },


		PV.StringFieldSchema("timeCaptured", {xpath:XPathExp("timeCaptured")}),
		PV.StringFieldSchema("minimumInboundOneWayTime", {xpath:XPathExp("minimumInboundOneWayTime")}),
		PV.StringFieldSchema("maximumInboundOneWayTime", {xpath:XPathExp("maximumInboundOneWayTime")}),
		PV.StringFieldSchema("averageInboundOneWayTime", {xpath:XPathExp("averageInboundOneWayTime")}),
		PV.StringFieldSchema("sumOfSquaresOneWayTime", {xpath:XPathExp("sumOfSquaresOneWayTime")}),
		PV.StringFieldSchema("minimumRoundTripTime", {xpath:XPathExp("minimumRoundTripTime")}),
		PV.StringFieldSchema("maximumRoundTripTime", {xpath:XPathExp("maximumRoundTripTime")}),
		PV.StringFieldSchema("averageRoundTripTime", {xpath:XPathExp("averageRoundTripTime")}),
		PV.StringFieldSchema("sumOfSquaresRoundTripTime", {xpath:XPathExp("sumOfSquaresRoundTripTime")}),
		PV.StringFieldSchema("inboundJitter", {xpath:XPathExp("inboundJitter")}),
		PV.StringFieldSchema("roundTripJitter", {xpath:XPathExp("roundTripJitter")}),
		PV.StringFieldSchema("lossPercentage", {xpath:XPathExp("lossPercentage")}),
		PV.StringFieldSchema("test", {xpath:XPathExp("test")})

						) // mpls.LspPingResult

					)  // XmlInputSchema




//
//  Names of the csv columns that we need to extract
//
var oamPingMetrics   = {
			"averageInboundOneWayTime":"One Way~Inbound (ms) (avg)",
			//			"sumOfSquaresOneWayTime",
			"averageRoundTripTime":"Round Trip~RTT (ms) (avg)",
			//			"sumOfSquaresRoundTripTime",
			"inboundJitter":"Jitter~Inbound Jitter (ms) (avg)",
			"roundTripJitter":"Jitter~Jitter (ms) (avg)",
			"lossPercentage":"Round Trip~Probes Lost (percent)"
};



//
//                p r o c e s s _ o a m _ p i n g _ r e s u l t s _ s t a t s
//...............................................................................................
// function to loop over the name defined above and create a metric object for each entry
//
function process_oam_ping_results_stats(record)
{
    var theMetric;
    var myId;
    var subelement = LOOKUP.get(record.test);

    logP4Msg("process_oam_ping_stats", "SAMUBA_oam_ping", "ENTERING");

    if(subelement == null)	{
		logP5Msg("process_oam_ping_stats", "SAMUBA_oam_ping", "Skipping 0 rid for --> "+ record.test);
		return;
	}
//    timestamp = Math.floor(record.timeCaptured/1000);
	myId = subelement.id;  
    logP4Msg("process_oam_ping_stats", "SAMUBA_oam_ping", "ENTERING for --> "+ record.test + " with id == " + myId);
	for(var i in oamPingMetrics)
	  if (isDef(record[i])) {
	  logP5Msg("process_OAM_ping_results_stats", "SAMUBA_OAM_ping_results", "adding metric " + i.toString() +" to SE " + record.test + " with id == " + myId);
	  if (!isNaN(record[i]))  {
		theMetric = OPERATOR.FloatMetric();
		theMetric.name = "AP~Generic~Latency~" + oamPingMetrics[i];
		theMetric.rid = myId;
		theMetric.value = record[i];
		OPERATOR.addMetric(theMetric);
	  logP4Msg("process_OAM_ping_results_stats", "SAMUBA_OAM_ping_results", "added metric " + i.toString() +"to SE" + record.test + " with id == " + myId);
	  } else {
	    logP5Msg("process_OAM_ping_results_stats", "SAMUBA_OAM_ping_results", "Skipping field " +i.toString() +" -- NaN");
	  }
	  }
	logP4Msg("process_oam_ping_stats", "SAMUBA_oam_ping", "LEAVING");

}
